@@ -1,9 +1,7 @@
 ####**********************************************************************
 ####**********************************************************************
 ####
-####  SPIKE AND SLAB 1.1.5
-####
-####  Copyright 2013, Cleveland Clinic Foundation
+####  SPIKE AND SLAB 1.1.6
 ####
 ####  This program is free software; you can redistribute it and/or
 ####  modify it under the terms of the GNU General Public License
@@ -23,41 +21,25 @@
 ####  ----------------------------------------------------------------
 ####  Written and Developed by:
 ####  ----------------------------------------------------------------
-####    Hemant Ishwaran, Ph.D.
-####    Director of Statistical Methodology
-####    Professor, Division of Biostatistics
-####    Clinical Research Building, Room 1058
-####    1120 NW 14th Street
-####    University of Miami, Miami FL 33136
+####  Hemant Ishwaran, Ph.D.
+####  Director of Statistical Methodology
+####  Professor, Division of Biostatistics
+####  Clinical Research Building, Room 1058
+####  1120 NW 14th Street
+####  University of Miami, Miami FL 33136
 ####
-####    email:  hemant.ishwaran@gmail.com
-####    URL:    http://web.ccs.miami.edu/~hishwaran
-####    --------------------------------------------------------------
-####    J. Sunil Rao, Ph. D.
-####    Professor and Director of the Division of Biostatistics, 
-####    Department of Epidemiology & Public Health
-####    Clinical Research Bldg, R-669
-####    1120 NW 14th Street, Room 1056
-####    Miami, FL 33136
-####    email:  rao.jsunil@gmail.com
-####    URL:    http://biostat.med.miami.edu/people/primary-faculty/sunil-rao
+####  email:  hemant.ishwaran@gmail.com
+####  URL:    https://ishwaran.org/
 ####  ----------------------------------------------------------------
-####  Maintained by:
-####    Udaya B. Kogalur, Ph.D.
-####    Adjunct Staff
-####    Dept of Quantitative Health Sciences
-####    Cleveland Clinic Foundation
-####    
-####    Kogalur & Company, Inc.
-####    5425 Nestleway Drive, Suite L1
-####    Clemmons, NC 27012
+####  Udaya B. Kogalur, Ph.D.
+####  Principal, Kogalur & Company, Inc.
+####  5425 Nestleway Drive, Suite L
+####  Clemmons, NC 27012
 ####
-####    email:  ubk@kogalur.com
-####    URL:    http://www.kogalur.com
-####    --------------------------------------------------------------
+####  email:  ubk@kogalur.com
+####  --------------------------------------------------------------
 ####
 ####**********************************************************************
-####**********************************************************************
 
 ### --------------------------------------------------------------
 ###
@@ -172,9 +154,9 @@ gnet.get <- function(Y, X, X.pt, phat, penal, mse = NULL, eps = .Machine$double.
   Y.org <- Y
   X <- rbind(X.org, diag(penal^0.5, ncol(X.org)))
   Y <- c(Y.org, rep(0, phat))
-  lasso.out <- lars(X, Y, intercept = FALSE, use.Gram = FALSE, type = "lar")
-  lasso.pred <- predict.lars(lasso.out, X.org, type = "fit", mode = "fraction")$fit
-  lasso.coef <- as.matrix(predict.lars(lasso.out, type = "coef", mode = "fraction")$coef)
+  lasso.out <- lars::lars(X, Y, intercept = FALSE, use.Gram = FALSE, type = "lar")
+  lasso.pred <- lars::predict.lars(lasso.out, X.org, type = "fit", mode = "fraction")$fit
+  lasso.coef <- as.matrix(lars::predict.lars(lasso.out, type = "coef", mode = "fraction")$coef)
   dof <- apply(lasso.coef, 1, function(x) {sum(abs(x) > eps)})
   aic.penal <- sapply(1:ncol(lasso.pred), function(j) {
       mean((Y.org - lasso.pred[, j])^2) + 2 * mse * dof[j] /n
